==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_el.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=el
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'στα μελλοντικά άρθρα μόνο (καμία δράση στη βάση δεδομένων).',
	'bouton_radio_articles_tous' => 'σε όλα τα άρθρα χωρίς εξαίρεση.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'σε όλα τα άρθρα,εκτός από αυτά για τα οποία είναι απενεργοποιημένο το φόρουμ.',
	'bouton_radio_enregistrement_obligatoire' => 'Απαραίτητη εγγραφή (οι χρήστες πρέπει να προσυπογράψουν με την παροχή της διεύθυνσης ηλεκτρονικού ταχυδρομείου τους πρίν είναι σε θέση να ταχυδρομηθούν οι συνεισφορές).',
	'bouton_radio_modere_abonnement' => 'απαιτείται εγγραφή',
	'bouton_radio_publication_immediate' => 'Αμεση δημοσίευση των μηνυμάτων (οι συνεισφορές θα παρουσιαστούν μόλις στέλνονται, οι διαχειριστές του ιστοχώρου μπορούν έπειτα να τις διαγράψουν).',

	// F
	'form_pet_message_commentaire' => 'Μήνυμα, σχόλιο ;',
	'forum' => 'Φόρουμ',
	'forum_acces_refuse' => 'Δεν έχετε πια πρόσβαση σε αυτά τα forum.',
	'forum_attention_dix_caracteres' => '<b>Προσοχή !</b> το μήνυμά σας πρέπει να περιέχει τουλάχιστον δέκα χαρακτήρες.',
	'forum_attention_trois_caracteres' => '<b>Προσοχή !</b> ο τίτλος σας θα πρέπει να περιέχει τουλάχιστον τρεις χαρακτήρες.',
	'forum_attention_trop_caracteres' => '<b>Προσοχή !</b> το μήνυμά σας είναι πολύ μεγάλο =(@compte@ caractères) : για να καταγραφεί δεν πρέπει να ξεπερνά τους @max@ χαρακτήρες.', # MODIF
	'forum_avez_selectionne' => 'Έχετε επιλέξει :',
	'forum_cliquer_retour' => 'Πατήστε <a href=\'@retour_forum@\'>εδώ</a> για να συνεχίσετε.',
	'forum_forum' => 'φόρουμ',
	'forum_info_modere' => 'Αυτό το φόρουμ είναι moderated : το μήνυμά σας θα εμφανιστεί αφού επικυρωθεί από τον administrator του site.', # MODIF
	'forum_lien_hyper' => '<b>Ενεργός δεσμός</b> (προαιρετικό)', # MODIF
	'forum_message_definitif' => 'Τελικό μήνυμα : αποστολή στο site',
	'forum_message_trop_long' => 'Το μήνυμά σας είναι πολύ μεγάλο. Το μέγιστο μήκος είναι 20000 χαρακτήρες.', # MODIF
	'forum_ne_repondez_pas' => 'Μην απαντήσετε σε αυτό το mail αλλά στο φόρουμ στην παρακάτω διεύθυνση :', # MODIF
	'forum_page_url' => '(Αν το μήνυμά σας αναφέρεται σε άρθρο που βρίσκεται στο Web, ή σε μία σελίδα που δίνει περισσότερες πληροφορίες, μπορείτε να εισάγετε τον τίτλο και τη διεύθυνση.)',
	'forum_poste_par' => 'Μήνυμα του/της@parauteur@ στο τέλος του άρθρου « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Ποιός είστε ?</b> (προαιρετικό)', # MODIF
	'forum_texte' => 'Κείμενο του μηνύματός σας :', # MODIF
	'forum_titre' => 'Τίτλος :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Επικυρώστε την επιλογή σας',
	'forum_voir_avant' => 'Δείτε το μήνυμα πριν την αποστολή του', # MODIF
	'forum_votre_email' => 'Διεύθνση ηλεκτρονικού ταχυδρομείου :', # MODIF
	'forum_votre_nom' => 'Ονομα (ή ψευδόνυμο) :', # MODIF
	'forum_vous_enregistrer' => 'Για να συμμετέχετε σε
  αυτό το φόρουμ πρέπει να είστε εγγεγραμμένος χρήστης. Δώστε
  το προσωπικό σας κωδικό
 Αν δεν είστε εγγεγραμμένος πρέπει',
	'forum_vous_inscrire' => 'να κάνετε εγγραφή.',

	// I
	'icone_poster_message' => 'Αποστολή μηνύματος',
	'icone_suivi_forum' => 'Συνέχιση του δημόσιου φόρουμ: @nb_forums@ συνεισφορες',
	'icone_suivi_forums' => 'Παρακολούθηση/διαχείρηση φόρουμ',
	'icone_supprimer_message' => 'Κατάργηση αυτού του μηνύματος',
	'icone_valider_message' => 'Επικύρωση μηνύματος',
	'info_desactiver_forum_public' => 'Απενεργοποιήστε την χρήση των δημόσιων
 φόρουμ. Τα δημόσια φόρουμ θα μπορούσαν να επιτραπούν σε ανά περίπτωση
 για τα άρθρα; θα είναι απαγορευμένα για τα τμήματα, τις ειδήσεις, κ.λπ....',
	'info_envoi_forum' => 'Στείλετε τα φόρουμ στους συντάκτες άρθρων',
	'info_fonctionnement_forum' => 'Λειτουργία φόρουμ:',

	// O
	'onglet_messages_internes' => 'Εσωτερικά μηνύματα',
	'onglet_messages_publics' => 'Μηνύματα για όλους',
	'onglet_messages_vide' => 'Μηνύματα χωρίς κείμενο',

	// R
	'repondre_message' => 'Απαντήστε σ\\`αυτο το μήνυμα',

	// S
	'statut_original' => 'πρωτότυπο',

	// T
	'titre_cadre_forum_interne' => 'Εσωτερικό φόρουμ',
	'titre_forum' => 'Φόρουμ'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_el.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=el
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'στα μελλοντικά άρθρα μόνο (καμία δράση στη βάση δεδομένων).',
	'bouton_radio_articles_tous' => 'σε όλα τα άρθρα χωρίς εξαίρεση.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'σε όλα τα άρθρα,εκτός από αυτά για τα οποία είναι απενεργοποιημένο το φόρουμ.',
	'bouton_radio_enregistrement_obligatoire' => 'Απαραίτητη εγγραφή (οι χρήστες πρέπει να προσυπογράψουν με την παροχή της διεύθυνσης ηλεκτρονικού ταχυδρομείου τους πρίν είναι σε θέση να ταχυδρομηθούν οι συνεισφορές).',
	'bouton_radio_modere_abonnement' => 'απαιτείται εγγραφή',
	'bouton_radio_publication_immediate' => 'Αμεση δημοσίευση των μηνυμάτων (οι συνεισφορές θα παρουσιαστούν μόλις στέλνονται, οι διαχειριστές του ιστοχώρου μπορούν έπειτα να τις διαγράψουν).',

	// F
	'form_pet_message_commentaire' => 'Μήνυμα, σχόλιο ;',
	'forum' => 'Φόρουμ',
	'forum_acces_refuse' => 'Δεν έχετε πια πρόσβαση σε αυτά τα forum.',
	'forum_attention_dix_caracteres' => '<b>Προσοχή !</b> το μήνυμά σας πρέπει να περιέχει τουλάχιστον δέκα χαρακτήρες.',
	'forum_attention_trois_caracteres' => '<b>Προσοχή !</b> ο τίτλος σας θα πρέπει να περιέχει τουλάχιστον τρεις χαρακτήρες.',
	'forum_attention_trop_caracteres' => '<b>Προσοχή !</b> το μήνυμά σας είναι πολύ μεγάλο =(@compte@ caractères) : για να καταγραφεί δεν πρέπει να ξεπερνά τους @max@ χαρακτήρες.', # MODIF
	'forum_avez_selectionne' => 'Έχετε επιλέξει :',
	'forum_cliquer_retour' => 'Πατήστε <a href=\'@retour_forum@\'>εδώ</a> για να συνεχίσετε.',
	'forum_forum' => 'φόρουμ',
	'forum_info_modere' => 'Αυτό το φόρουμ είναι moderated : το μήνυμά σας θα εμφανιστεί αφού επικυρωθεί από τον administrator του site.', # MODIF
	'forum_lien_hyper' => '<b>Ενεργός δεσμός</b> (προαιρετικό)', # MODIF
	'forum_message_definitif' => 'Τελικό μήνυμα : αποστολή στο site',
	'forum_message_trop_long' => 'Το μήνυμά σας είναι πολύ μεγάλο. Το μέγιστο μήκος είναι 20000 χαρακτήρες.', # MODIF
	'forum_ne_repondez_pas' => 'Μην απαντήσετε σε αυτό το mail αλλά στο φόρουμ στην παρακάτω διεύθυνση :', # MODIF
	'forum_page_url' => '(Αν το μήνυμά σας αναφέρεται σε άρθρο που βρίσκεται στο Web, ή σε μία σελίδα που δίνει περισσότερες πληροφορίες, μπορείτε να εισάγετε τον τίτλο και τη διεύθυνση.)',
	'forum_poste_par' => 'Μήνυμα του/της@parauteur@ στο τέλος του άρθρου « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Ποιός είστε ?</b> (προαιρετικό)', # MODIF
	'forum_texte' => 'Κείμενο του μηνύματός σας :', # MODIF
	'forum_titre' => 'Τίτλος :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Επικυρώστε την επιλογή σας',
	'forum_voir_avant' => 'Δείτε το μήνυμα πριν την αποστολή του', # MODIF
	'forum_votre_email' => 'Διεύθνση ηλεκτρονικού ταχυδρομείου :', # MODIF
	'forum_votre_nom' => 'Ονομα (ή ψευδόνυμο) :', # MODIF
	'forum_vous_enregistrer' => 'Για να συμμετέχετε σε
  αυτό το φόρουμ πρέπει να είστε εγγεγραμμένος χρήστης. Δώστε
  το προσωπικό σας κωδικό
 Αν δεν είστε εγγεγραμμένος πρέπει',
	'forum_vous_inscrire' => 'να κάνετε εγγραφή.',

	// I
	'icone_poster_message' => 'Αποστολή μηνύματος',
	'icone_suivi_forum' => 'Συνέχιση του δημόσιου φόρουμ: @nb_forums@ συνεισφορες',
	'icone_suivi_forums' => 'Παρακολούθηση/διαχείρηση φόρουμ',
	'icone_supprimer_message' => 'Κατάργηση αυτού του μηνύματος',
	'icone_valider_message' => 'Επικύρωση μηνύματος',
	'info_desactiver_forum_public' => 'Απενεργοποιήστε την χρήση των δημόσιων
 φόρουμ. Τα δημόσια φόρουμ θα μπορούσαν να επιτραπούν σε ανά περίπτωση
 για τα άρθρα; θα είναι απαγορευμένα για τα τμήματα, τις ειδήσεις, κ.λπ....',
	'info_envoi_forum' => 'Στείλετε τα φόρουμ στους συντάκτες άρθρων',
	'info_fonctionnement_forum' => 'Λειτουργία φόρουμ:',

	// O
	'onglet_messages_internes' => 'Εσωτερικά μηνύματα',
	'onglet_messages_publics' => 'Μηνύματα για όλους',
	'onglet_messages_vide' => 'Μηνύματα χωρίς κείμενο',

	// R
	'repondre_message' => 'Απαντήστε σ\\`αυτο το μήνυμα',

	// S
	'statut_original' => 'πρωτότυπο',

	// T
	'titre_cadre_forum_interne' => 'Εσωτερικό φόρουμ',
	'titre_forum' => 'Φόρουμ',
];
